==> akonadi-0.81.0.tar.bz2: akonadi-0.81.0/server/src/handler/fetch.h <==
/***************************************************************************
 *   Copyright (C) 2006 by Tobias Koenig <tokoe@kde.org>                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef AKONADIFETCH_H
#define AKONADIFETCH_H

#include <handler.h>

#include "../../libs/imapset_p.h"

#include "storage/datastore.h"

namespace Akonadi {

class ImapSet;
class QueryBuilder;

/**
  @ingroup akonadi_server_handler

  Handler for the fetch command.
 */
class Fetch : public Handler
{
  public:
    Fetch();

    ~Fetch();

    bool handleLine(const QByteArray& line);

  private:
    bool parseCommand( const QByteArray &line );
    void updateItemAccessTime();
    void triggerOnDemandFetch();
    QueryBuilder buildPartQuery( const QStringList &partList );

  private:
    ImapSet mSet;
    QList<QByteArray> mAttrList;
    bool mIsUidFetch;
    bool mAllParts;
    bool mCacheOnly;
};

}

#endif

==> akonadi-1.0.0.tar.bz2: akonadi-1.0.0/server/src/handler/fetch.h <==
/***************************************************************************
 *   Copyright (C) 2006 by Tobias Koenig <tokoe@kde.org>                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef AKONADIFETCH_H
#define AKONADIFETCH_H

#include <handler.h>

#include "../../libs/imapset_p.h"

#include "storage/datastore.h"

namespace Akonadi {

class ImapSet;
class QueryBuilder;

/**
  @ingroup akonadi_server_handler

  Handler for the fetch command.
 */
class Fetch : public Handler
{
  public:
    Fetch();

    ~Fetch();

    bool handleLine(const QByteArray& line);

  private:
    void parseCommand( const QByteArray &line );
    void updateItemAccessTime();
    void triggerOnDemandFetch();
    void buildItemQuery();
    QueryBuilder buildPartQuery( const QStringList &partList, bool allPayload, bool allAttrs );
    void retrieveMissingPayloads( const QStringList &payloadList );

  private:
    QueryBuilder mItemQuery;
    ImapSet mSet;
    QList<QByteArray> mRequestedParts;
    bool mIsUidFetch;
    bool mCacheOnly;
    bool mFullPayload;
    bool mAllAttrs;
};

}

#endif
